@@ -2,8 +2,7 @@ from holour.msg.geometry import Vector3, Pose, Poses, AxisAngle
 from holour.msg.status import Status
 from holour.msg.force_torque import ForceTorque
 from holour.msg.script import Script, WaypointConfig
-from holour.msg.task import Task
+from holour.msg.task import Task, TaskMessage
 from holour.msg.product import Product
-from holour.msg.process import Process
-from holour.msg.assembly import AddProcess, MoveTask, CompleteTask, Destination, ConfirmNeeded, ConfirmTask, TaskStatus
+from holour.msg.process import Process, ProcessMessage
 from holour.msg.robot import ProgramState
