@@ -15,7 +15,7 @@ class Task:
     ASSIGNED_TO_ROBOT = "robot"
 
     def __init__(self, uuid: str, name: str, product_uuid: str, pose: Pose, agents: List[str],
-                 assigned_to: str = ASSIGNED_TO_HUMAN, conditions: List[str] = None, conditions_fulfilled: bool = True,
+                 assigned_to: str, conditions: List[str] = None, conditions_fulfilled: bool = True,
                  can_undo: bool = False, description: str = "", status: str = '', _type: str = ''):
         conditions = conditions if conditions else []
         status = status if status else self.STATUS_MISSING_PRECONDITION if len(conditions) > 0 else self.STATUS_WAITING
